@@ -17,11 +17,17 @@ def test_calculate_noise():
         'test_data/ref_nochr.fa',
         'test_data/SeraCare_0-5.bam',
         'test_data/test.bed',
-        0.2
+        0.2,
+        output_prefix='test_'
     )
-    assert noise == approx(0.001228501228, rel=1e-6)
+    assert noise == approx(0.00245398773005833, rel=1e-6)
 
-    for filename in [OUTPUT_NOISE_FILENAME, OUTPUT_PILEUP_NAME]:
+    for filename in [
+            'test_' + OUTPUT_PILEUP_NAME,
+            'test_noise_acgt.tsv',
+            'test_noise_del.tsv',
+            'test_noise_n.tsv',
+    ]:
         assert os.path.exists(filename)
         os.unlink(filename)
 
